package App::MigrateModules;

use strict;
use warnings;

our $VERSION = '0.003';

1;

=head1 NAME

App::MigrateModules - Migrate installed CPAN modules from one Perl to another

=head1 DESCRIPTION

See L<perl-migrate-modules>.

=head1 BUGS

Report any issues on the public bugtracker.

=head1 AUTHOR

Dan Book <dbook@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Dan Book.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)
